@@ -84,7 +84,7 @@ def analyze(
     output_format,
     verbose,
 ):
-    """Analyze a file or directory of EMLs, MSGs, or MDMs."""
+    """Analyze a file or directory of EMLs, MSGs, MDMs or MBOX files."""
     request_permission()
 
     if not run_path and not query:
@@ -135,50 +135,78 @@ def analyze(
     # analyze each file and aggregate all responses
     results = {}
     num_files = len(file_paths)
-    for i in range(num_files):
-        file_path = file_paths[i]
-        file_dir, _, file_name = file_path.rpartition('/')
-        _, _, extension = file_name.rpartition('.')
+    with Halo(text="", spinner='dots') as halo:
+        for i in range(num_files):
+            halo.start()
+            file_path = file_paths[i]
+            file_dir, _, file_name = file_path.rpartition('/')
+            _, _, extension = file_name.rpartition('.')
+            halo_text = f"Analyzing file {i+1} of {num_files} ( {file_name} )"
+            halo.text = halo_text
 
-        with Halo(
-            text=f'Analyzing file {i+1} of {num_files} ( {file_name} )...',
-            spinner='dots'
-        ):
             if file_path.endswith('.mdm'):
-                message_data_model = load_message_data_model(file_path)
-                response = api_client.analyze_message(
-                        message_data_model,
-                        rules,
-                        queries)
+                try:
+                    message_data_model = load_message_data_model(file_path)
+                    response = api_client.analyze_message(
+                            message_data_model,
+                            rules,
+                            queries)
+                except Exception as exception:
+                    halo.stop()
+                    LOGGER.warning(f"failed to analyze ({file_name}): {exception}")
+                    continue
 
             elif file_path.endswith('.msg'):
-                raw_message = load_msg(file_path)
-                response = api_client.analyze_raw_message(
-                        raw_message, 
-                        rules,
-                        queries,
-                        mailbox_email_address,
-                        message_type)
-
-            elif file_path.endswith('.eml'):
-                raw_message = load_eml(file_path)
-                response = api_client.analyze_raw_message(
-                        raw_message, 
-                        rules,
-                        queries,
-                        mailbox_email_address,
-                        message_type)
-
-            elif file_path.endswith('.mbox'):
-                # in the mbox case we want to retrieve the response for each message
-                # contained and provide a unique results key for each entry
-                for subject_unique, raw_message in load_mbox(file_path).items():
+                try:
+                    raw_message = load_msg(file_path)
                     response = api_client.analyze_raw_message(
                             raw_message, 
                             rules,
                             queries,
                             mailbox_email_address,
                             message_type)
+                except Exception as exception:
+                    halo.stop()
+                    LOGGER.warning(f"failed to analyze ({file_name}): {exception}")
+                    continue
+
+            elif file_path.endswith('.eml'):
+                try:
+                    raw_message = load_eml(file_path)
+                    response = api_client.analyze_raw_message(
+                            raw_message, 
+                            rules,
+                            queries,
+                            mailbox_email_address,
+                            message_type)
+                except Exception as exception:
+                    halo.stop()
+                    LOGGER.warning(f"failed to analyze ({file_name}): {exception}")
+                    continue
+
+            elif file_path.endswith('.mbox'):
+                # in the mbox case we want to retrieve the response for each message
+                # contained and provide a unique results key for each entry
+                mbox_files = load_mbox(file_path, halo=halo)
+                file_count = len(mbox_files)
+
+                count = 0
+                for subject_unique in mbox_files.keys():
+                    count += 1
+                    halo_suffix = f" message {count} of {file_count}..."
+                    halo.text = halo_text + halo_suffix
+                    try:
+                        response = api_client.analyze_raw_message(
+                                mbox_files[subject_unique], 
+                                rules,
+                                queries,
+                                mailbox_email_address,
+                                message_type)
+                    except Exception as exception:
+                        halo.stop()
+                        LOGGER.warning(f"failed to analyze ({file_name}) {subject_unique}: {exception}")
+                        continue
+
                     response['file_name'] = file_name
                     response['extension'] = extension
                     response['directory'] = file_dir
@@ -194,7 +222,7 @@ def analyze(
             response['extension'] = extension
             response['directory'] = file_dir
             results[file_path] = response
- 
+
     return results
 
 
@@ -239,7 +267,7 @@ def feedback(
         help="Default save directory for items retrieved from your Sublime environment")
 def setup(api_key="", save_dir=""):
     """Configure defaults."""
-    config = {"api_key": api_key, "save_dir": save_dir}
+    config = {"api_key": api_key, "save_dir": save_dir, "permission": ""}
     save_config(config)
     click.echo("Configuration saved to {!r}".format(CONFIG_FILE))
 
